# library(meifly)
lapply(dir("~/documents/meifly/meifly/R", "\\.[Sr]$", full.name=T), source)
